# Duve3PygameUtil
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)

[![PyPI - Version](https://img.shields.io/pypi/v/duve3pygameutil.svg)](https://pypi.org/project/duve3pygameutil)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/duve3pygameutil.svg)](https://pypi.org/project/duve3pygameutil)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [Documentation](#documentation)

## Installation

```console
pip install duve3pygameutil
```

## License

`Duve3PygameUtil` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Documentation
will add eventually... (probably gonna be readthedocs.io link)
